@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0205';
 
 use Moo;
 use strictures 2;
@@ -41,6 +41,12 @@ has counts => (
 );
 
 
+has file_tfidf => (
+    is       => 'ro',
+    init_arg => undef,
+);
+
+
 sub BUILD {
     my ( $self, $args ) = @_;
 
@@ -127,11 +133,11 @@ sub tfidf_by_file {
 
             next if $seen{$word}++ || !defined $tfidf;
 
-            $self->{tfidf_by_file}{$file}{$word} = $tfidf;
+            $self->{file_tfidf}{$file}{$word} = $tfidf;
         }
     }
 
-    return $self->{tfidf_by_file};
+    return $self->{file_tfidf};
 }
 
 1;
@@ -148,7 +154,7 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.0204
+version 0.0205
 
 =head1 SYNOPSIS
 
@@ -193,6 +199,11 @@ Boolean indicating that phrases with stopwords will be ignored.  Default is 1.
 HashRef of the ngram counts of each processed file.  This is a computed
 attribute - providing it in the constructor will be ignored.
 
+=head2 file_tfidf
+
+HashRef of the TF-IDF values in each processed file.  This is a computed
+attribute - providing it in the constructor will be ignored.
+
 =head1 METHODS
 
 =head2 new
@@ -239,10 +250,16 @@ Construct a HashRef of all files with all phrases and their B<tfidf> values.
 
 =head1 SEE ALSO
 
-L<Moo>
-
 L<https://en.wikipedia.org/wiki/Tf%E2%80%93idf>
 
+L<Lingua::EN::Ngram>
+
+L<Lingua::StopWords>
+
+L<List::Util>
+
+L<Moo>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
